---
name: "Feature request \U0001F9BE"
about: Tell us about features that are missing
title: ''
labels: ''
assignees: ''

---

# Feature request

## Summary

*Describe the feature you would like to see added in short*

## Reason and benefit

*Please describe why you cannot achieve your goal with the existing features or how the feature would benefit Eradiate*

## Details

*Please provide details necessary to implement the requested feature. This can include references to theoretical descriptions of models or implementations in other code.*
